    <li class="nav-item dropdown">
        <a class="nav-item nav-link dropdown-toggle mr-md-2" href="#" id="bd-versions" data-toggle="dropdown"
           aria-haspopup="true" aria-expanded="false">
            DE
        </a>
        <div class="dropdown-menu dropdown-menu-right" aria-labelledby="bd-versions">
            <a class="dropdown-item active" href="//de.openlegaldata.io/">DE</a>
            <div class="dropdown-divider"></div>
            <a class="dropdown-item" href="//openlegaldata.io/">International</a>
        </div>
    </li>