{% load static %}
{% load i18n %}
{% load contact %}

{% block footer %}

<footer class="bd-footer text-muted">
    <div class="container-fluid p-3 p-md-5">
        <ul class="bd-footer-links">

            <li><a href="{% url 'contact:form' %}">{% trans 'Contact' %}</a></li>
            <li><a href="{% url 'flatpages' url='/imprint/' %}">{% trans 'Imprint' %}</a></li>
            <li><a href="{% url 'flatpages' url='/privacy/' %}">{% trans 'Privacy' %}</a></li>
            <li><a href="{% report_content_url %}" rel="nofollow">{% trans 'Report content' %}</a></li>
            <li><a href="{% url 'flatpages' url='/api/' %}">API</a></li>
            <li><a href="//openlegaldata.io/about">Über uns (Englisch)</a></li>
            <li><a href="{{ site_blog_url }}">Blog</a></li>

            <li><a href="//openlegaldata.io"><i class="fa fa-globe"></i> International</a></li>

            <li><a href="{{ site_discord_url }}"><i class="fa-brands fa-discord" aria-hidden="true"></i> Discord</a></li>
            <li><a href="{{ site_github_url }}"><i class="fa-brands fa-github" aria-hidden="true"></i> GitHub</a></li>
            <li><a href="{{ site_linkedin_url }}"><i class="fa-brands fa-linkedin" aria-hidden="true"></i> LinkedIn</a></li>

        </ul>
    </div>
</footer>

{% endblock %}